@@ -34,7 +34,7 @@ to_mu_sd_weibull <- function(k, lambda) {
 #'
 #' The purpose of this function is to convert the parameterization of Weibull distribution in the form of
 #' mean and standard deviation to the form of shape and scale. It can be used for specifying the initial
-#' values for the EM algorithm when the first-hand intial values are in the form of mean and standard
+#' values for the EM algorithm when the first-hand initial values are in the form of mean and standard
 #' deviation from K-means clustering algorithm.
 #'
 #' @param mu a numeric vector representing the means of Weibull distributions
@@ -53,7 +53,29 @@ to_mu_sd_weibull <- function(k, lambda) {
 #'
 #' @export
 to_k_lambda_weibull <- function(mu, sd) {
-	k <- (sd / mu)^(-1.086)
-	lambda <- mu / gamma(1 + 1/k)
-	list(k = k, lambda = lambda)
+  to_k_lambda_weibull_inner <- function(mu, sd) {
+    delta <- (mu / sd)^2
+    f <- function(z) {
+      (1 + delta) * gamma(z)^2 - delta * gamma(2 * z -1)
+    }
+    
+    # initial values for z_right (z_left is kept at 1 as f(1) is always 1)
+    z_right <- 2
+    while (f(z_right) > 0) z_right <- z_right * 2
+    
+    # find root of f(z) = 0
+    z_root <- uniroot(f, c(1, z_right))$root
+    k <- 1 / (z_root - 1)
+    lambda <- mu / gamma(z_root)
+    
+    list(k = k, lambda = lambda)
+  }
+  k <- lambda <- numeric(length(mu))
+  for(i in 1:length(mu)) {
+    res <- to_k_lambda_weibull_inner(mu[i], sd[i])
+    k[i] <- res$k
+    lambda[i] <- res$lambda
+  }
+  
+  list(k = k, lambda = lambda)
 }
